from pymatgen.core.structure import Structure
from pymatgen.analysis.ferroelectricity.polarization import Polarization, calc_ionic, zval_dict_from_potcar, get_total_ionic_dipole
from pymatgen.io.vasp.inputs import Poscar, Potcar
from pymatgen.io.vasp.outputs import Outcar

num_structs = 10
poscars = [Structure.from_file("POSCAR-" + str(i)) for i in range(num_structs)]
outcars = [Outcar("OUTCAR-" + str(i)) for i in range(num_structs)]
potcar=Potcar.from_file("POTCAR")
for i in range(num_structs):
    outcars[i].zval_dict = zval_dict_from_potcar(potcar)


pol_from_out_struct_method = Polarization.from_outcars_and_structures(outcars,poscars,
    calc_ionic_from_zval = True)
print(pol_from_out_struct_method.get_same_branch_polarization_data(convert_to_muC_per_cm2=True))

pol_from_out_struct_custom = Polarization([o.p_elec for o in outcars], [o.p_ion for o in outcars],
    poscars, p_ions_in_cartesian=True)
print(pol_from_out_struct_custom.get_same_branch_polarization_data(convert_to_muC_per_cm2=True))

pol_from_get_total_ionic = Polarization([o.p_elec for o in outcars],
    [get_total_ionic_dipole(poscars[i], outcars[i].zval_dict) for i in range(len(outcars))], poscars)
print(pol_from_get_total_ionic.get_same_branch_polarization_data(convert_to_muC_per_cm2=True))

#get_total_ionic_dipole is working when passed the structure generated from the poscar file
#and the zval dict from the potcar
